@@ -9,11 +9,12 @@ class TrialTest(test.test):
     """
 
     user_options = test.test.user_options + [
-        ('rterrors', 'e', "realtime errors, print out tracebacks as soon as they occur"),
-        ('debug-stacktraces', 'B', "Report Deferred creation and callback stack traces"),
-        ('coverage','c', "Report coverage data"),
-        ('reactor=','r', "Which reactor to use"),
-        ('reporter=', None, "Customize Trial's output with a Reporter plugin"),
+        ('rterrors', 'e', "Realtime errors: print out tracebacks as soon as they occur."),
+        ('debug-stacktraces', 'B', "Report Deferred creation and callback stack traces."),
+        ('coverage','c', "Report coverage data."),
+        ('reactor=','r', "which reactor to use"),
+        ('reporter=', None, "Customize Trial's output with a Reporter plugin."),
+        ('until-failure','u', "Repeat test until it fails."),
     ]
 
     boolean_options = ['coverage', 'debug-stacktraces', 'rterrors']
@@ -25,6 +26,7 @@ class TrialTest(test.test):
         self.reactor = None
         self.reporter = None
         self.rterrors = None
+        self.until_failure = None
 
     def finalize_options(self):
         if self.test_suite is None:
@@ -54,6 +56,14 @@ class TrialTest(test.test):
         cmd_options = []
         if self.reactor is not None:
             cmd_options.extend(['--reactor', self.reactor])
+        else:
+            # Cygwin requires the poll reactor to work at all.  Linux requires the poll reactor
+            # to avoid twisted bug #3218.  In general, the poll reactor is better than the
+            # select reactor, but it is not available on all platforms.  According to exarkun on
+            # IRC, it is available but buggy on some versions of Mac OS X, so just because you
+            # can install it doesn't mean we want to use it on every platform.
+            if sys.platform in ("linux2", "cygwin"):
+                cmd_options.extend(['--reactor', 'poll'])
         if self.reporter is not None:
             cmd_options.extend(['--reporter', self.reporter])
         if self.rterrors is not None:
@@ -77,7 +87,7 @@ class TrialTest(test.test):
         suite = trial._getSuite(config)
 
         # run the tests
-        if config['until-failure']:
+        if self.until_failure:
             test_result = trialRunner.runUntilFailure(suite)
         else:
             test_result = trialRunner.run(suite)
